/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.openrune.entity;

/**
 * An Entity within the game.
 * <p>
 * An Entity can be many different things within the game, 
 * and this class contains methods that can apply to any entity
 * within the game.
 * @author ry60003333
 */
public interface Entity
{
    /**
     * Get the index of the Entity within it's manager's list.
     * <p>
     * This index is guaranteed to stay constant as long as the
     * Entity is not removed from it's manager's list. However, 
     * plugins should <b>NOT</b> keep track of Entities by their
     * index, as the Entity occupying a specific index can change.
     * <p>
     * Instead, keep a reference to the Entity and check the isExpired()
     * method to see if the Entity has been removed from it's manager's list.
     * @return The index of the Entity within it's manager's list.
     */
    public int getIndex();
    
    /**
     * Check if the Entity is expired.
     * <p>
     * An expired Entity has been removed from it's parent manager's 
     * list and is no longer valid for use on the game. The Entity
     * will not be shown to players and will not be updated by
     * the main game loop. If an expired Entity is detected, 
     * plugins should release all references to the Entity, or
     * a memory leak may result.
     * @return If the Entity is expired.
     */
    public boolean isExpired();
}
