/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.openrune.event;

/**
 * Handles GameEvents generated by the server.
 * <p>
 * An EventHandler can accept any type of GameEvent, but
 * generally you want an EventHandler to only handle a
 * specific type of GameEvent. The Handler can check the type
 * of GameEvent it received using the <b>instanceof</b> operator.
 * @author ry60003333
 */
public interface EventHandler
{
    /**
     * Handle a GameEvent generated by the game engine.
     * <p>
     * The GameEvent can generally be down casted to the type
     * of GameEvent that the EventHandler was registered to
     * listen for. However, EventHandlers should always use
     * the <b>instanceof</b> operator to double check before
     * casting to avoid throwing a ClassCastException.
     * <p>
     * After handling a GameEvent, this method should return
     * <b>true</b> in order to allow other handlers to receive the GameEvent.
     * If propagation of the GameEvent should halt, this method should
     * return <b>false</b>.
     * @param event The event to handle.
     * @return If the GameEvent should continue on to other EventHandlers.
     */
    public boolean handle(GameEvent event);
}
